// --------------------------------------------------------------------------------------------------------------------
// <summary>
//    Defines the FirstViewModel type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

using System.Collections.Generic;
using System.Collections.ObjectModel;
using MultiBinding.Core.Models;

namespace MultiBinding.Core.ViewModels
{
    using System.Windows.Input;

    using Cirrious.MvvmCross.ViewModels;

    /// <summary>
    /// Define the FirstViewModel type.
    /// </summary>
    public class FirstViewModel : BaseViewModel
    {

        private readonly ObservableCollection<Person> people = new ObservableCollection<Person>();

        public ObservableCollection<Person> People { get { return people; } }

        private TitleResponse title;

        public TitleResponse Title
        {
            get { return title; }
            set
            {
                if (value == title) return;
                title = value;
                RaisePropertyChanged(() => Title);
            }
        }

        private string firstName;
        public string FirstName
        {
            get { return firstName; }
            set
            {
                if (value == firstName) return;
                firstName = value;
                RaisePropertyChanged(() => FirstName);
            }
        }

        private string lastName;
        public string LastName
        {
            get { return lastName; }
            set
            {
                if (value == lastName) return;
                lastName = value;
                RaisePropertyChanged(() => LastName);
            }
        }

        private bool accepted;
        public bool Accepted
        {
            get { return accepted; }
            set
            {
                if (value == accepted) return;
                accepted = value;
                RaisePropertyChanged(() => Accepted);
            }
        }

        private readonly List<TitleResponse> titles = new List<TitleResponse>
                                                 {
                                                     TitleResponse.None,
                                                     TitleResponse.Mr,
                                                     TitleResponse.Dr,
                                                     TitleResponse.Mrs,
                                                     TitleResponse.Ms,
                                                     TitleResponse.Miss
                                                 };

        public List<TitleResponse> Titles { get { return titles; } }


        public ICommand AddCommand
        {
            get
            {
                return new MvxCommand(() =>
                {
                    if (!Accepted)
                        return;

                    People.Add(new Person()
                    {
                        FirstName = FirstName,
                        LastName = LastName,
                        Title = Title
                    });

                    Title = TitleResponse.None;
                    FirstName = "";
                    LastName = "";
                    Accepted = false;
                });
            }
        }




    }
}
